(* ASCII character code for carriage return character *)
let carriage_return : int = 13;;

(* computes length not including possible terminal carriage-return *)
(* useful on Windows machines for accurate line length calculation *)
let visible_length (s:string) : int =
  let len = String.length s in
  if len > 0 then
    if Char.code (String.get s (len-1)) = carriage_return then 
      len - 1 
    else 
      len
  else
    len
;;  

(* prints warning for every line whose visible length exceeds 80 characters *)
(* terminates with End_of_file exception *)
let rec loop (line_no:int) : unit =
  let len = visible_length (read_line()) in
  if len > 80 then    
     Printf.printf "line %d: %d characters\n" line_no len;
  loop (line_no+1)
;;

let main () =
  try
    loop 1
  with End_of_file -> ()
;;

main();;
